==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AssigningSeriesStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HighlightingInfoDescriptionMetadata } from "./HighlightingInfoDescriptionMetadata";
/**
 * @hidden
 */
export let AssigningSeriesStyleEventArgsBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningSeriesStyleEventArgsBaseDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a == null) {
                AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a);
            }
            if (a.k(AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a)) {
                return;
            }
            a.aa(AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a);
            HighlightingInfoDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("StartIndex", "Number:int");
            a.item("EndIndex", "Number:int");
            a.item("StartDate", "Date");
            a.item("EndDate", "Date");
            a.item("GetItemsRef", "(w:GetItems,wf:GetItems)MethodRef");
            a.item("Fill", "Brush");
            a.item("Stroke", "Brush");
            a.item("Opacity", "Number:double");
            a.item("FadeOpacity", "Number:double");
            a.item("HighlightingInfo", "ExportedType:HighlightingInfo");
            a.item("MaxAllSeriesHighlightingProgress", "Number:double");
            a.item("SumAllSeriesHighlightingProgress", "Number:double");
            a.item("TotalAllSeriesHighlightingProgress", "Number:double");
            a.item("HighlightingHandled", "Boolean");
            a.item("HasDateRange", "Boolean");
            a.item("IsNegativeShape", "Boolean");
            a.item("IsThumbnail", "Boolean");
        }
        static d(a) {
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.b(a);
            a.ab("AssigningSeriesStyleEventArgsBase", AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a);
        }
    }
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningSeriesStyleEventArgsBaseDescriptionMetadata, 'AssigningSeriesStyleEventArgsBaseDescriptionMetadata');
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningSeriesStyleEventArgsBaseDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/AssigningSeriesStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HighlightingInfoDescriptionMetadata } from "./HighlightingInfoDescriptionMetadata";
/**
 * @hidden
 */
export let AssigningSeriesStyleEventArgsBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningSeriesStyleEventArgsBaseDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a == null) {
                AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a);
            }
            if (a.k(AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a);
            HighlightingInfoDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("StartIndex", "Number:int");
            a.item("EndIndex", "Number:int");
            a.item("StartDate", "Date");
            a.item("EndDate", "Date");
            a.item("GetItemsRef", "(w:GetItems,wf:GetItems)MethodRef");
            a.item("Fill", "Brush");
            a.item("Stroke", "Brush");
            a.item("Opacity", "Number:double");
            a.item("FadeOpacity", "Number:double");
            a.item("HighlightingInfo", "ExportedType:HighlightingInfo");
            a.item("SelectionHighlightingInfo", "ExportedType:HighlightingInfo");
            a.item("FocusHighlightingInfo", "ExportedType:HighlightingInfo");
            a.item("MaxAllSeriesHighlightingProgress", "Number:double");
            a.item("SumAllSeriesHighlightingProgress", "Number:double");
            a.item("MaxAllSeriesSelectionHighlightingProgress", "Number:double");
            a.item("SumAllSeriesSelectionHighlightingProgress", "Number:double");
            a.item("MaxAllSeriesFocusHighlightingProgress", "Number:double");
            a.item("SumAllSeriesFocusHighlightingProgress", "Number:double");
            a.item("TotalAllSeriesHighlightingProgress", "Number:double");
            a.item("TotalAllSeriesHighWaterMark", "Number:double");
            a.item("TotalAllSeriesFocusHighWaterMark", "Number:double");
            a.item("TotalAllSeriesSelectionHighWaterMark", "Number:double");
            a.item("TotalAllSeriesSelectionHighlightingProgress", "Number:double");
            a.item("TotalAllSeriesFocusHighlightingProgress", "Number:double");
            a.item("HighlightingHandled", "Boolean");
            a.item("HasDateRange", "Boolean");
            a.item("IsNegativeShape", "Boolean");
            a.item("IsThumbnail", "Boolean");
        }
        static d(a) {
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.b(a);
            a.ad("AssigningSeriesStyleEventArgsBase", AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a);
        }
    }
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningSeriesStyleEventArgsBaseDescriptionMetadata, 'AssigningSeriesStyleEventArgsBaseDescriptionMetadata');
    AssigningSeriesStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningSeriesStyleEventArgsBaseDescriptionMetadata;
})();
